@@ -64,7 +64,7 @@ class SampleFactory:
 
     def run_job(self):
         popen_command = self.environs.popen_command
-        with open('out.log') as out_log, open('err.log') as err_log:
+        with open('out.log', mode='w') as out_log, open('err.log', mode='w') as err_log:
             for script in self.bash_scripts:
                 if self.debug==False:
                     # Open a pipe to the command.
@@ -80,8 +80,8 @@ class SampleFactory:
                 if self.debug==False:
                     print(err)
                     print(out)
-                    out_log.write(out)
-                    err_log.write(err)
+                    out_log.write(str(out))
+                    err_log.write(str(err))
                 
                 time.sleep(0.1)
 
